draw_fermi — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# draw_fermi

DOSPlot.draw_fermi(value, orientation: str = 'horizontal')

  A method to draw the fermi surface

  Parameters:

    - orientation (str, optional) – Boolean to plot vertical or horizontal, by default ‘horizontal’

    - color (str, optional) – A color , by default “blue”

    - linestyle (str, optional) – THe line style, by default “dotted”

    - linewidth (float, optional) – The linewidth, by default 1

  Returns:

    None – None